Vivarium
========

.. image:: https://badge.fury.io/py/vivarium.svg
    :target: https://badge.fury.io/py/vivarium

.. image:: https://travis-ci.org/ihmeuw/vivarium.svg?branch=develop
    :target: https://travis-ci.org/ihmeuw/vivarium
    :alt: Latest Version

.. image:: https://readthedocs.org/projects/vivarium/badge/?version=latest
    :target: https://vivarium.readthedocs.io/en/latest/?badge=latest
    :alt: Latest Docs

.. image:: https://zenodo.org/badge/96817805.svg
   :target: https://zenodo.org/badge/latestdoi/96817805

Vivarium is a framework for microsimulation written using standard scientific Python tools.

You can install ``vivarium`` from PyPI with pip:

  ``> pip install vivarium``

or build it from source with

  ``> git clone https://github.com/ihmeuw/vivarium.git``

  ``> cd vivarium``

  ``> python setup.py install``

This will make the ``vivarium`` library available to python and install a command-line executable called ``simulate``
that you can use to verify your installation with

  ``> simulate test``

Visit us at https://vivarium.readthedocs.io/en/latest/
